function [leftward_1, leftward_2, rightward_1, rightward_2] = ABmodel()

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  File: ABmodel.m
%%  Author: Nicole Rust; Excerpt from motionTutorial.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%stim = eye(16);

% First, we construct two (one-dimensional) spatial filters:
nx=15;  %number of spatial samples in the filter
maxX =1;     %Half-width of Gabor (pixels)
xFilt = linspace(-maxX,maxX,nx);
sx=0.5;   %standard deviation of Gaussian
sfx=1.1;  %spatial freqency of carrier
gaussX = exp(-xFilt.^2/sx.^2); 	%Gaussian envelope
sdfilt = cos(2*pi*sfx*xFilt).*gaussX; 	%Even Gabor
sfilt = sin(2*pi*sfx*xFilt).*gaussX; 	%Odd Gabor

% Next, create two causal temporal filters, one that contains more
% ripples than the other:
tsz = 9;
tfilt = 2*temp_imp_resp(5,16,[0:tsz]'/tsz);
tdfilt = temp_imp_resp(2.5,16,[0:tsz]'/tsz);

% And now we create separable filters by taking the outer products of
% the four combinations of spatial  and temporal filters:
even_slow = tfilt * sdfilt;
even_fast = tdfilt * sdfilt ;
odd_slow = tfilt * sfilt ;
odd_fast = tdfilt * sfilt ;

% Construct space-time oriented filters

leftward_1=odd_fast+even_slow; 
leftward_2=-odd_slow+even_fast;
rightward_1=-odd_fast+even_slow;
rightward_2=odd_slow+even_fast;

rightward_1=2.*flipud([rightward_1; zeros(1,nx)]);
rightward_2=2.*flipud([rightward_2; zeros(1,nx)]);
leftward_1=2.*flipud([leftward_1; zeros(1,nx)]);
leftward_2=2.*flipud([leftward_2; zeros(1,nx)]);
mx = max(max(abs(rightward_2)));

figure
subplot(2,2,1)
imagesc(rightward_1,[-mx mx]); title('rightward 1');
subplot(2,2,2)
imagesc(rightward_2,[-mx mx]);title('rightward 2');
subplot(2,2,3)
imagesc(leftward_1,[-mx mx]);title('leftward 1');
subplot(2,2,4)
imagesc(leftward_2,[-mx mx]);title('leftward 1');
colormap(gray)