% "Spike"-triggered analysis tutorial
% This tutorial uses continuous neural activity (not spikes) but
% illustrates the principles of spike triggered averages 

%% Stimuli
% We simulate a "retina" that has nrX inputs with coordinates x 
x           = (-1:0.1:1)';
nrX         = numel(x);
% In each "trial" we'll present one noise pattern for 'duration' ms and 
% record the number of spikes in response to the pattern
nrTrials    = 1000;
duration    = 250;
totalTime   = duration*nrTrials/(60*1000);

% Generate stimuli using independent draws from a Gaussian distribution for
% all positions and trials ("noise")
stimuli = randn(nrX,nrTrials);

% Define some convenience functions that implement nonlinearities
halfwave    = @(x) ((x>0).*x);


%% Assignment:
% 1. Visualize the stimuli
% 2. Visualize the nonlinearities.

%% Two simulated neurons:

% Each simulated neuron has a Gabor linear receptive field:
rf =  exp(-(x.^2)).*cos(2*pi*x);
% But they have differen nonlinearities. We define two (anonymous) functions 
% that can take any stimulus input and return the neuron's response
linearCell  = @(stimulus) ((stimulus'*rf)'); % An (impossible) linear neuron 
simpleCell  = @(stimulus) (halfwave(stimulus'*rf)'); % A halfwave rectifying neuron

% Simulate the response of each of the neurons.
linearResponse = linearCell(stimuli);
simpleCellResponse = simpleCell(stimuli);

%% Assignment:
% 3. Show the stimulus and each neuron's response for 10 of the noise trials.
% 4. Show a contrast response function for each neuron by stimulating it
% with a stimulus that matches the receptive field, multiplied by a scalar
% (the contrast ) that runs from -1 to +1.

%% Spike triggered averaging (=correlation)
% Determine the STA for each of the neurons: multiply the response with the
% stimulus that generated it, then take the average. (i.e. a response
% weighted average)
staLinear = mean(repmat(linearResponse,[nrX 1]).*stimuli,2);
staSimple = mean(repmat(simpleCellResponse,[nrX 1]).*stimuli,2);


%% Assignment
% 5. Show the STA for each of the model neurons as well as the RF in the same plot. Use a
% legend.
% 5b. Vary the nonlinearity (i.e. replace halfwave with something else in
% the simpleCell function) and see what happens.
 
%% Assignment
% 6. Change teh xxxCell function definitions to explore how adding noise 
% to the neural response affects the STA. What kind of noise did you
% simulate? What could you do in an experiment to reduce the influence of
% noise on your STA?

