% STC demo. Please run staContinuous.m first.
%

%% Build a complex cell response
fullwave    = @(x) (abs(x));
scale       = @(x) (x./max(x));
complexCell  = @(stimulus) (fullwave(stimulus'*rf)'); % A fullwave rectifying neuron
complexCellResponse = complexCell(stimuli);

% Determine the STA of the complex cell. It should be flat/noise
staComplex = mean(repmat(complexCellResponse,[nrX 1]).*stimuli,2);

figure(1);
clf;
hold on
plot(x,scale(staComplex));
plot(x,rf);
xlabel 'Position'
ylabel 'Sensitivity'
title 'STA of a Complex Cell'
legend('STA','Ground Truth')

%% Instead of spike-triggered average, determine the spike triggered covariance:
% Determne the spike triggered stimuli
stStimsComplex  = (repmat(complexCellResponse,[nrX 1]).*stimuli)';
% And their covariance.
stCov = innerProd(stStimsComplex);

% The filters are eigenvectors of the stCov matrix
[filters,eigenvals] = sortedEig(stCov);  
eigenvals = diag(eigenvals);

% Althouhg all eigenvectors are potential filters, only the ones that have
% unusually large or small eigenvalues contribute significantly.

figure(2);
clf;
plot(eigenvals,'.');
xlabel 'Component Number (sorted)'
ylabel 'Eigenvalue'
title 'Eigenvalue spectrum'

% Only the first one is relevant in this case (becuase we constructed the
% complex cell model that way; a single RF filter).

figure(3);
clf;
hold on
plot(x,scale(staComplex));
plot(x,scale(filters(:,1)));
plot(x,rf);
xlabel 'Position'
ylabel 'Sensitivity'
title 'LN Model of a Complex Cell'
legend('STA','STC#1','Ground Truth')



